
Acknowledgements
================

    * Martin Fitzpatrick

        - Tutorial for the multithreading code

    * Yusuke Kamiyamane

        - Some icons Licensed under a Creative Commons Attribution 3.0 License.

    * Smashicons_ from FLATICON_

        - Application icon
        - license under `Creative Commons BY 3.0`_

.. _Smashicons: https://www.flaticon.com/authors/smashicons
.. _FLATICON: https://www.flaticon.com
.. _`Creative Commons BY 3.0`: http://creativecommons.org/licenses/by/3.0
